@@ -55,15 +55,15 @@ class FileInterface():
 
     def grab_proper(self):
 
-        if(os.path.exists(pp)): return None
-        with open(pp ,'r') as f: 
+        if(os.path.exists(self.path)): return None
+        with open(self.path ,'r') as f: 
             try:    v = self.recover(json.loads(f.read() or ""))
             except: v = None
 
         return v
 
     def pull(self, auto_repair = False):
-        proper_pulled = self.grab_proper(self.path) 
+        proper_pulled = self.grab_proper() 
         if(proper_pulled is not None): 
             self.value = proper_pulled
             if(auto_repair):
